Crate ploidy_pointer

Crate ploidy_pointer 

Structs

JsonPointer
A JSON Pointer.
JsonPointerBuf
An owned JSON Pointer.
JsonPointerKeyError
An error that occurs when a pointed-to value doesn’t have a key that the pointer references, with an optional suggestion for the correct key.
JsonPointerKeyErrorContext
JsonPointerSegment
A single segment of a JsonPointer.
JsonPointerSegments
A borrowing iterator over the segments of a JsonPointer.
JsonPointerSyntaxError
An error that occurs during parsing.
JsonPointerTargetError
An error returned when a JsonPointerTarget can’t extract a typed value from a type-erased JsonPointee because the pointee’s type doesn’t match the target type.
JsonPointerTypeError
An error that occurs when a pointer can’t be resolved against a value of the given type.

Enums

JsonPointeeError
An error that occurs during traversal.
JsonPointeeStructTy
The name of a pointed-to struct type or enum variant, for reporting traversal errors.
JsonPointeeType
The name of a pointed-to type, for reporting traversal errors.
JsonPointerError
An error that occurs during pointer resolution.

Traits

JsonPointee
A value that a JsonPointer points to.
JsonPointeeExt
Convenience methods for JsonPointee types.
JsonPointerTarget
Extracts a typed value from a JsonPointee.

Derive Macros

JsonPointee
Derives the JsonPointee trait for JSON Pointer (RFC 6901) traversal.
JsonPointerTarget
Derives the JsonPointerTarget trait for downcasting a type-erased JsonPointee reference to a concrete type reference.