JsonPointer

Struct JsonPointer 

pub struct JsonPointer(/* private fields */);
A JSON Pointer.

Implementations

Source

impl JsonPointer

pub fn parse(s: &str) -> Result<&Self, JsonPointerSyntaxError>

Parses a pointer from an RFC 6901 string.

The empty string is the valid root pointer. All other strings must start with /.

pub fn empty() -> &'static Self

Returns the empty root pointer.

pub fn is_empty(&self) -> bool

Returns true if this is the empty root pointer.

pub fn head(&self) -> Option<&JsonPointerSegment>

Returns the first segment, or None for the root pointer.

pub fn tail(&self) -> &JsonPointer

Returns the pointer without its first segment.

For the root pointer, returns the root pointer.

pub fn segments(&self) -> JsonPointerSegments<'_>

Returns a borrowing iterator over the segments.

pub fn follow<'a, T: JsonPointerTarget<'a>>( &self, root: &'a (impl JsonPointee + ?Sized), ) -> Result<T, JsonPointerError>

Follows this pointer through root and extracts the result as T.