Struct JsonPointerSegment
Source pub struct JsonPointerSegment();
Returns the value of this segment as a string.
Returns the value of this segment as an array index,
or None if this segment can’t be used as an index.
Returns true if this segment is empty.
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Converts the given value to a
String.
Read more