Structs
- Json
Pointer - A JSON Pointer.
- Json
Pointer Buf - An owned JSON Pointer.
- Json
Pointer KeyError - An error that occurs when a pointed-to value doesn’t have a key that the pointer references, with an optional suggestion for the correct key.
- Json
Pointer KeyError Context - Json
Pointer Segment - A single segment of a
JsonPointer. - Json
Pointer Segments - A borrowing iterator over the segments of a
JsonPointer. - Json
Pointer Syntax Error - An error that occurs during parsing.
- Json
Pointer Target Error - An error returned when a
JsonPointerTargetcan’t extract a typed value from a type-erasedJsonPointeebecause the pointee’s type doesn’t match the target type. - Json
Pointer Type Error - An error that occurs when a pointer can’t be resolved against a value of the given type.
Enums
- Json
Pointee Error - An error that occurs during traversal.
- Json
Pointee Struct Ty - The name of a pointed-to struct type or enum variant, for reporting traversal errors.
- Json
Pointee Type - The name of a pointed-to type, for reporting traversal errors.
- Json
Pointer Error - An error that occurs during pointer resolution.
Traits
- Json
Pointee - A value that a
JsonPointerpoints to. - Json
Pointee Ext - Convenience methods for
JsonPointeetypes. - Json
Pointer Target - Extracts a typed value from a
JsonPointee.
Derive Macros
- Json
Pointee - Derives the
JsonPointeetrait for JSON Pointer (RFC 6901) traversal. - Json
Pointer Target - Derives the
JsonPointerTargettrait for downcasting a type-erasedJsonPointeereference to a concrete type reference.