pub struct JsonPointer(/* private fields */);Expand description
A JSON Pointer.
Implementations
Sourceimpl JsonPointer
impl JsonPointer
Sourcepub fn parse(s: &str) -> Result<&Self, JsonPointerSyntaxError>
pub fn parse(s: &str) -> Result<&Self, JsonPointerSyntaxError>
Parses a pointer from an RFC 6901 string.
The empty string is the valid root pointer.
All other strings must start with /.
Sourcepub fn head(&self) -> Option<&JsonPointerSegment>
pub fn head(&self) -> Option<&JsonPointerSegment>
Returns the first segment, or None for the root pointer.
Sourcepub fn tail(&self) -> &JsonPointer
pub fn tail(&self) -> &JsonPointer
Returns the pointer without its first segment.
For the root pointer, returns the root pointer.
Sourcepub fn segments(&self) -> JsonPointerSegments<'_> ⓘ
pub fn segments(&self) -> JsonPointerSegments<'_> ⓘ
Returns a borrowing iterator over the segments.
Sourcepub fn follow<'a, T: JsonPointerTarget<'a>>(
&self,
root: &'a (impl JsonPointee + ?Sized),
) -> Result<T, JsonPointerError>
pub fn follow<'a, T: JsonPointerTarget<'a>>( &self, root: &'a (impl JsonPointee + ?Sized), ) -> Result<T, JsonPointerError>
Follows this pointer through root and extracts the result as T.