JsonPointerSegment

Struct JsonPointerSegment 

pub struct JsonPointerSegment(/* private fields */);
A single segment of a JsonPointer.

Implementations

Source

impl JsonPointerSegment

pub fn to_str(&self) -> Cow<'_, str>

Returns the value of this segment as a string.

pub fn to_index(&self) -> Option<usize>

Returns the value of this segment as an array index, or None if this segment can’t be used as an index.